mysql.conversion.input

Package mysql :: Package conversion :: Module input |
[hide private]
[frames] | no frames]

# Module input

source code

Input Conversion converts Python data types to be made appropriate for MySQL parameters.

The main function of these conversions for simple data types is to escape them (such as escaping quotes in strings). It also handles converting more elaborate data structures, such as datetime objects, to strings that MySQL can parse.

The base class Input_Conversion defines the API for converting values.

The class Basic_Conversion is the default conversion used if you do not specify a conversion instance.

Classes | [hide private]
`` | Input_Conversion Base class for the input conversion API.
`` | Basic_Conversion The default conversion class used if none is specified.

Variables | [hide private]
`` | __version__ = `'$Revision: 1.5 $'`

Variables Details | [hide private]

    ### __version__ Value:
        '$Revision: 1.5 $'